@@ -142,6 +142,8 @@ class Speaker(caching.base.CachingMixin,models.Model):
         for w in words:
             if settings.DEBUG:
                 print(w.pk)
+            if not w.WordType.isAcceptable():
+                continue
             if not w.isAcceptable():
                 continue
             if str(w.Dialog) == 's2003' or str(w.Dialog) =='s4001':
@@ -359,6 +361,13 @@ class WordType(caching.base.CachingMixin,models.Model):
     def __unicode__(self):
         return u'%s' % self.Label
 
+    def isAcceptable(self):
+        qs = self.wordtoken_set.filter(Output__isnull=False)
+        if len(qs) > 0:
+            if 'CelexCategory' in qs[0].Output and qs[0].Output['CelexCategory'] not in ['N','V','ADV','A']:
+                return False
+        return True
+
     def getUR(self,stressed=False,blick_style=False):
         t = ' '.join([s.getStrTrans() for s in self.underlying_set.all()])
         if not stressed:
